summaryrefslogtreecommitdiffstats
path: root/libkdepim/interfaces/MailTransportServiceIface.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/interfaces/MailTransportServiceIface.h')
-rw-r--r--libkdepim/interfaces/MailTransportServiceIface.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/libkdepim/interfaces/MailTransportServiceIface.h b/libkdepim/interfaces/MailTransportServiceIface.h
index d0ced70a..99228d25 100644
--- a/libkdepim/interfaces/MailTransportServiceIface.h
+++ b/libkdepim/interfaces/MailTransportServiceIface.h
@@ -25,8 +25,8 @@
#include <dcopobject.h>
#include <dcopref.h>
#include <kurl.h>
-#include <qstring.h>
-#include <qcstring.h>
+#include <tqstring.h>
+#include <tqcstring.h>
#include <kdepimmacros.h>
@@ -46,23 +46,23 @@ namespace KPim {
*
* @return true when the message was send successfully, false on failure.
**/
- virtual bool sendMessage( const QString& from, const QString& to,
- const QString& cc, const QString& bcc,
- const QString& subject, const QString& body,
+ virtual bool sendMessage( const TQString& from, const TQString& to,
+ const TQString& cc, const TQString& bcc,
+ const TQString& subject, const TQString& body,
const KURL::List& attachments ) = 0;
/**
* This method basically behaves like the one above, but takes only one
* attachment as QByteArray. This is useful if you want to attach simple
* text files (e.g. a vCalendar). The mimetype is determined using
* mime magic.
*
* @return true when the message was send successfully, false on failure.
**/
- virtual bool sendMessage( const QString& from, const QString& to,
- const QString& cc, const QString& bcc,
- const QString& subject, const QString& body,
- const QByteArray& attachment ) = 0;
+ virtual bool sendMessage( const TQString& from, const TQString& to,
+ const TQString& cc, const TQString& bcc,
+ const TQString& subject, const TQString& body,
+ const TQByteArray& attachment ) = 0;
k_dcop_hidden:
/**
@@ -70,9 +70,9 @@ namespace KPim {
* additional parameter from instead.
**/
// FIXME KDE 4.0: Remove this.
- virtual bool sendMessage( const QString& to,
- const QString& cc, const QString& bcc,
- const QString& subject, const QString& body,
+ virtual bool sendMessage( const TQString& to,
+ const TQString& cc, const TQString& bcc,
+ const TQString& subject, const TQString& body,
const KURL::List& attachments ) = 0;
/**
@@ -80,10 +80,10 @@ namespace KPim {
* additional parameter from instead.
**/
// FIXME KDE 4.0: Remove this.
- virtual bool sendMessage( const QString& to,
- const QString& cc, const QString& bcc,
- const QString& subject, const QString& body,
- const QByteArray& attachment ) = 0;
+ virtual bool sendMessage( const TQString& to,
+ const TQString& cc, const TQString& bcc,
+ const TQString& subject, const TQString& body,
+ const TQByteArray& attachment ) = 0;
};
@@ -46,23 +46,23 @@ namespace KPim {
/**
* This method basically behaves like the one above, but takes only one
- * attachment as QByteArray. This is useful if you want to attach simple
+ * attachment as TQByteArray. This is useful if you want to attach simple
* text files (e.g. a vCalendar). The mimetype is determined using
* mime magic.